/*
  Copyright 2010-2018 Grégory Soutadé

  This file is part of KissCount.

  KissCount is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  KissCount is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with KissCount.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "TransfertDialog.hpp"
#include <QLabel>

TransfertDialog::TransfertDialog(KissCount* kiss, User* user, Operation& curOperation,
				 int* selectedAccount, bool* groupOperations) :
    QDialog(0, Qt::Dialog), _kiss(kiss), _outSelectedAccount(selectedAccount),
    _outGroupOperations(groupOperations)
{
    std::vector<Account>::iterator accountIt;
    QGridLayout* gridLayout;
    Operation op_tmp;
    bool hasPrevious;
    int selectedIndex = -1, curIndex = 0;

    gridLayout = new QGridLayout(this);

    setWindowTitle(_("Create Transfert"));
    setModal(true);

    gridLayout->addWidget(new QLabel(_("Transfert to "), this), 0, 0);

    _account = new QComboBox(this);
    gridLayout->addWidget(_account, 0, 1);

    _ok = new QPushButton(_("OK"), this);
    QPushButton* cancel = new QPushButton(_("Cancel"), this);
    gridLayout->addWidget(_ok, 0, 2);
    gridLayout->addWidget(cancel, 1, 2);

    if(_kiss->SearchPreviousOperation(&op_tmp, curOperation, curOperation.month,
				      curOperation.year, true, 1))
    {
	hasPrevious = (op_tmp.transfert)?true:false;
    }

    for (accountIt = user->_accounts.begin();
         accountIt != user->_accounts.end();
         accountIt++, curIndex++)
    {
	if (accountIt->id != curOperation.account &&
	    accountIt->validAt(curOperation.month, curOperation.year))
	{
	    _account->addItem(accountIt->name);
	    _accounts.push_back(accountIt->id);
	    if (hasPrevious && accountIt->id == op_tmp.account)
		selectedIndex = curIndex;
	}
    }

    if (selectedIndex != -1)
	_account->setCurrentIndex(selectedIndex);

    _groupOperations = new QCheckBox(_("Group operations"));
    _groupOperations->setChecked(true);
    gridLayout->addWidget(_groupOperations, 1, 1);

    connect(_ok, SIGNAL(clicked()), this, SLOT(OnOK()));
    connect(cancel, SIGNAL(clicked()), this, SLOT(OnCancel()));

    _ok->setFocus();
}

void TransfertDialog::OnOK()
{
    *_outSelectedAccount = _accounts[_account->currentIndex()];
    *_outGroupOperations = (_groupOperations->checkState() == Qt::Checked);
    done(1);
}

void TransfertDialog::OnCancel()
{
    *_outSelectedAccount = -1;
    done(0);
}
